@@ -16,14 +16,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
 #ifndef _EAB_CONTACT_DISPLAY_H_
 #define _EAB_CONTACT_DISPLAY_H_
 
-#include <gtk/gtkvbox.h>
 #include <gtkhtml/gtkhtml.h>
 #include <libebook/e-contact.h>
 
@@ -43,13 +42,13 @@ typedef enum {
 } EABContactDisplayRenderMode;
 
 struct _EABContactDisplay {
-	GtkVBox parent;
-	
+	GtkHTML parent;
+
 	EABContactDisplayPrivate *priv;
 };
 
 struct _EABContactDisplayClass {
-	GtkVBoxClass parent_class;
+	GtkHTMLClass parent_class;
 };
 
 GtkType        eab_contact_display_get_type    (void);
