@@ -83,7 +83,7 @@ struct _MemoPagePrivate {
 	GtkWidget *to_button;
 	GtkWidget *to_hbox;
 	GtkWidget *to_entry;
-	
+
 	/* Summary */
 	GtkWidget *summary_label;
 	GtkWidget *summary_entry;
@@ -91,7 +91,7 @@ struct _MemoPagePrivate {
 	/* Start date */
 	GtkWidget *start_label;
 	GtkWidget *start_date;
-	
+
 	GtkWidget *categories_btn;
 	GtkWidget *categories;
 
@@ -129,10 +129,10 @@ G_DEFINE_TYPE (MemoPage, memo_page, TYPE_COMP_EDITOR_PAGE)
 
 /**
  * memo_page_get_type:
- * 
+ *
  * Registers the #TaskPage class if necessary, and returns the type ID
  * associated to it.
- * 
+ *
  * Return value: The type ID of the #TaskPage class.
  **/
 
@@ -150,7 +150,7 @@ memo_page_class_init (MemoPageClass *klass)
 	editor_page_class->focus_main_widget = memo_page_focus_main_widget;
 	editor_page_class->fill_widgets = memo_page_fill_widgets;
 	editor_page_class->fill_component = memo_page_fill_component;
-	
+
 	object_class->finalize = memo_page_finalize;
 }
 
@@ -194,7 +194,7 @@ memo_page_finalize (GObject *object)
 
 	mpage = MEMO_PAGE (object);
 	priv = mpage->priv;
-	
+
 	for (l = priv->address_strings; l != NULL; l = l->next)
 		g_free (l->data);
 	g_list_free (priv->address_strings);
@@ -286,7 +286,7 @@ clear_widgets (MemoPage *mpage)
 	e_dialog_editable_set (priv->categories, NULL);
 }
 
-void 
+void
 memo_page_set_classification (MemoPage *page, ECalComponentClassification class)
 {
 	page->priv->classification = class;
@@ -297,32 +297,32 @@ sensitize_widgets (MemoPage *mpage)
 {
 	gboolean read_only, sens = FALSE, sensitize;
 	MemoPagePrivate *priv;
-	
+
 	priv = mpage->priv;
 
 	if (!e_cal_is_read_only (COMP_EDITOR_PAGE (mpage)->client, &read_only, NULL))
 		read_only = TRUE;
-	
+
 	if (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_IS_SHARED)
 	 	sens = COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_USER_ORG;
 	else
 		sens = TRUE;
 
 	sensitize = (!read_only && sens);
-	
+
 	priv = mpage->priv;
 
-	/* The list of organizers is set to be non-editable. Otherwise any 
- 	* change in the displayed list causes an 'Account not found' error. 
+	/* The list of organizers is set to be non-editable. Otherwise any
+ 	* change in the displayed list causes an 'Account not found' error.
  	*/
 	gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (priv->org_combo)->entry), FALSE);
-	
+
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (priv->memo_content), sensitize);
 	gtk_widget_set_sensitive (priv->start_date, sensitize);
 	gtk_widget_set_sensitive (priv->categories_btn, !read_only);
 	gtk_editable_set_editable (GTK_EDITABLE (priv->categories), !read_only);
 	gtk_editable_set_editable (GTK_EDITABLE (priv->summary_entry), sensitize);
-	
+
 	if (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_IS_SHARED) {
 		if (priv->to_entry) {
 			gtk_editable_set_editable (GTK_EDITABLE (priv->to_entry), !read_only);
@@ -357,18 +357,18 @@ memo_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	priv = mpage->priv;
 
 	priv->updating = TRUE;
-	
+
 	/* Clean the screen */
 	clear_widgets (mpage);
 
         /* Summary */
 	e_cal_component_get_summary (comp, &text);
 	e_dialog_editable_set (priv->summary_entry, text.value);
-	
+
 	e_cal_component_get_description_list (comp, &l);
 	if (l && l->data) {
 		ECalComponentText *dtext;
-		
+
 		dtext = l->data;
 		gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->memo_content)),
 					  dtext->value ? dtext->value : "", -1);
@@ -398,7 +398,7 @@ memo_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 			break;
 		}
 	case E_CAL_COMPONENT_CLASS_PRIVATE:
-		{	
+		{
 			cl = E_CAL_COMPONENT_CLASS_PRIVATE;
 			break;
 		}
@@ -446,7 +446,7 @@ memo_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 		}
 	}
 
-	if (backend_addr) 
+	if (backend_addr)
 		g_free (backend_addr);
 
 	/* Source */
@@ -461,7 +461,7 @@ memo_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	return TRUE;
 }
 
-static gboolean 
+static gboolean
 fill_comp_with_recipients (ENameSelector *name_selector, ECalComponent *comp)
 {
 	EDestinationStore *destination_store;
@@ -504,16 +504,16 @@ fill_comp_with_recipients (ENameSelector *name_selector, ECalComponent *comp)
 						break;
 					}
 				}
-				
+
 				if (book) {
 					GList *contacts = NULL;
 					EContact *n_con = NULL;
 					char *qu;
 					EBookQuery *query;
 
-					qu = g_strdup_printf ("(is \"full_name\" \"%s\")", 
+					qu = g_strdup_printf ("(is \"full_name\" \"%s\")",
 							(char *) e_contact_get (contact, E_CONTACT_FULL_NAME));
-					query = e_book_query_from_string (qu); 
+					query = e_book_query_from_string (qu);
 
 					if (!e_book_get_contacts (book, query, &contacts, NULL)) {
 						g_warning ("Could not get contact from the book \n");
@@ -524,35 +524,36 @@ fill_comp_with_recipients (ENameSelector *name_selector, ECalComponent *comp)
 						e_destination_set_contact (des, n_con, 0);
 						list_dests = e_destination_list_get_dests (des);
 
-						g_list_foreach (contacts, (GFunc) g_object_unref, NULL); 	 
+						g_list_foreach (contacts, (GFunc) g_object_unref, NULL);
 						g_list_free (contacts);
 					}
 
 					e_book_query_unref (query);
 					g_free (qu);
 				}
+				g_list_free (books);
 			} else {
 				card_dest.next = NULL;
 				card_dest.prev = NULL;
 				card_dest.data = destination;
 				list_dests = &card_dest;
 			}
-		}		
-		
+		}
+
 		for (l = list_dests; l; l = l->next) {
 			EDestination *dest = l->data;
 			const char *name, *attendee = NULL;
-			
+
 			name = e_destination_get_name (dest);
 
 			/* If we couldn't get the attendee prior, get the email address as the default */
 			if (attendee == NULL || *attendee == '\0') {
 				attendee = e_destination_get_email (dest);
 			}
-		
+
 			if (attendee == NULL || *attendee == '\0')
 				continue;
-		
+
 			if (!str) {
 				str = g_string_new (NULL);
 				g_string_prepend (str, attendee);
@@ -570,7 +571,7 @@ fill_comp_with_recipients (ENameSelector *name_selector, ECalComponent *comp)
 		icalprop = icalproperty_new_x (str->str);
 		icalproperty_set_x_name (icalprop, "X-EVOLUTION-RECIPIENTS");
 		icalcomponent_add_property (icalcomp, icalprop);
-		
+
 		g_string_free (str, FALSE);
 		return TRUE;
 	} else
@@ -579,17 +580,17 @@ fill_comp_with_recipients (ENameSelector *name_selector, ECalComponent *comp)
 
 static EAccount *
 get_current_account (MemoPage *page)
-{	
+{
 	MemoPagePrivate *priv;
 	EIterator *it;
 	const char *str;
-	
+
 	priv = page->priv;
 
 	str = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (priv->org_combo)->entry));
 	if (!str)
 		return NULL;
-	
+
 	for (it = e_list_get_iterator((EList *)priv->accounts); e_iterator_is_valid(it); e_iterator_next(it)) {
 		EAccount *a = (EAccount *)e_iterator_get(it);
 		char *full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
@@ -600,12 +601,12 @@ get_current_account (MemoPage *page)
 
 			return a;
 		}
-	
+
 		g_free (full);
 	}
 	g_object_unref (it);
-	
-	return NULL;	
+
+	return NULL;
 }
 
 /* fill_component handler for the memo page */
@@ -685,7 +686,7 @@ memo_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 		l.next = NULL;
 
 		e_cal_component_set_description_list (comp, &l);
-		
+
 		g_free(txt);
 	}
 
@@ -707,7 +708,7 @@ memo_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 					       &start_tt.month,
 					       &start_tt.day))
 		e_cal_component_set_dtstart (comp, &start_date);
-	else 
+	else
 		e_cal_component_set_dtstart (comp, NULL);
 
 	/* Classification. */
@@ -729,7 +730,7 @@ memo_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 
 		EAccount *a;
 		gchar *backend_addr = NULL, *org_addr = NULL, *sentby = NULL;
- 
+
 		e_cal_get_cal_address (page->client, &backend_addr, NULL);
 
 		/* Find the identity for the organizer or sentby field */
@@ -737,16 +738,16 @@ memo_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 
 		/* Sanity Check */
 		if (a == NULL) {
-			e_notice (page, GTK_MESSAGE_ERROR,
+			e_notice (priv->main, GTK_MESSAGE_ERROR,
 					_("The organizer selected no longer has an account."));
-			return FALSE;			
+			return FALSE;
 		}
 
 		if (a->id->address == NULL || strlen (a->id->address) == 0) {
-			e_notice (page, GTK_MESSAGE_ERROR,
+			e_notice (priv->main, GTK_MESSAGE_ERROR,
 					_("An organizer is required."));
 			return FALSE;
-		} 
+		}
 
 		if (!(backend_addr && *backend_addr) || !g_ascii_strcasecmp (backend_addr, a->id->address)) {
 			org_addr = g_strdup_printf ("MAILTO:%s", a->id->address);
@@ -777,7 +778,7 @@ memo_page_set_show_categories (MemoPage *page, gboolean state)
 {
 	if (state) {
 		gtk_widget_show (page->priv->categories_btn);
-		gtk_widget_show (page->priv->categories);	
+		gtk_widget_show (page->priv->categories);
 	} else {
 		gtk_widget_hide (page->priv->categories_btn);
 		gtk_widget_hide (page->priv->categories);
@@ -785,7 +786,7 @@ memo_page_set_show_categories (MemoPage *page, gboolean state)
 }
 
 /*If the msg has some value set, the icon should always be set */
-void 
+void
 memo_page_set_info_string (MemoPage *mpage, const gchar *icon, const gchar *msg)
 {
 	MemoPagePrivate *priv;
@@ -796,9 +797,9 @@ memo_page_set_info_string (MemoPage *mpage, const gchar *icon, const gchar *msg)
 	gtk_label_set_text (GTK_LABEL(priv->info_string), msg);
 
 	if (msg && icon)
-		gtk_widget_show (priv->info_hbox); 
+		gtk_widget_show (priv->info_hbox);
 	else
-		gtk_widget_hide (priv->info_hbox); 
+		gtk_widget_hide (priv->info_hbox);
 }
 
 /* Gets the widgets from the XML file and returns if they are all available. */
@@ -836,7 +837,7 @@ get_widgets (MemoPage *mpage)
 
 	priv->org_label = GW ("org-label");
 	priv->org_combo = GW ("org-combo");
-	
+
 	priv->to_button = GW ("to-button");
 	priv->to_hbox = GW ("to-hbox");
 
@@ -845,7 +846,7 @@ get_widgets (MemoPage *mpage)
 
 	priv->start_label = GW ("start-label");
 	priv->start_date = GW ("start-date");
-	
+
 	priv->memo_content = GW ("memo_content");
 
 	priv->categories_btn = GW ("categories-button");
@@ -884,10 +885,10 @@ field_changed_cb (GtkWidget *widget, gpointer data)
 {
 	MemoPage *mpage;
 	MemoPagePrivate *priv;
-	
+
 	mpage = MEMO_PAGE (data);
 	priv = mpage->priv;
-	
+
 	if (!priv->updating)
 		comp_editor_page_notify_changed (COMP_EDITOR_PAGE (mpage));
 }
@@ -947,13 +948,13 @@ set_subscriber_info_string (MemoPage *mpage, const char *backend_address)
 {
 	ECal *client = COMP_EDITOR_PAGE (mpage)->client;
 	ESource *source;
-	
+
 	source = e_cal_get_source (client);
-	
+
 	if (e_source_get_property (source, "subscriber"))
-		/* Translators: This string is used when we are creating a Memo 
+		/* Translators: This string is used when we are creating a Memo
 		   on behalf of some other user */
-		memo_page_set_info_string (mpage, GTK_STOCK_DIALOG_INFO, 
+		memo_page_set_info_string (mpage, GTK_STOCK_DIALOG_INFO,
 				g_strdup_printf(_("You are acting on behalf of %s"), backend_address));
 	else
 		memo_page_set_info_string (mpage, NULL, NULL);
@@ -990,13 +991,13 @@ summary_changed_cb (GtkEditable *editable, gpointer data)
 	MemoPage *mpage;
 	MemoPagePrivate *priv;
 	gchar *summary;
-	
+
 	mpage = MEMO_PAGE (data);
 	priv = mpage->priv;
-	
+
 	if (priv->updating)
 		return;
-	
+
 	summary = e_dialog_editable_get (GTK_WIDGET (editable));
 	comp_editor_page_notify_summary_changed (COMP_EDITOR_PAGE (mpage),
 						 summary);
@@ -1004,12 +1005,12 @@ summary_changed_cb (GtkEditable *editable, gpointer data)
 }
 
 static void
-to_button_clicked_cb (GtkButton *button, gpointer data) 
+to_button_clicked_cb (GtkButton *button, gpointer data)
 {
 	MemoPage *page = data;
 	MemoPagePrivate *priv = page->priv;
 	ENameSelectorDialog *name_selector_dialog;
-	
+
 	name_selector_dialog = e_name_selector_peek_dialog (priv->name_selector);
 	gtk_widget_show (GTK_WIDGET (name_selector_dialog));
 }
@@ -1057,7 +1058,7 @@ init_widgets (MemoPage *mpage)
 	/* Source selector */
 	g_signal_connect((priv->source_selector), "changed",
 			 G_CALLBACK (source_changed_cb), mpage);
-	
+
 	/* Connect the default signal handler to use to make sure the "changed"
 	   field gets set whenever a field is changed. */
 
@@ -1067,13 +1068,13 @@ init_widgets (MemoPage *mpage)
 
 	g_signal_connect((priv->categories), "changed",
 			    G_CALLBACK (field_changed_cb), mpage);
-	
+
 	g_signal_connect((priv->summary_entry), "changed",
 			    G_CALLBACK (field_changed_cb), mpage);
-	
+
 	g_signal_connect((priv->source_selector), "changed",
 			 G_CALLBACK (field_changed_cb), mpage);
-	
+
 	g_signal_connect((priv->start_date), "changed",
 			 G_CALLBACK (field_changed_cb), mpage);
 
@@ -1081,13 +1082,13 @@ init_widgets (MemoPage *mpage)
 		ENameSelectorDialog *name_selector_dialog;
 
 		name_selector_dialog = e_name_selector_peek_dialog (priv->name_selector);
-		
+
 		g_signal_connect (name_selector_dialog, "response",
 			  G_CALLBACK (response_cb), mpage);
 		g_signal_connect ((priv->to_button), "clicked", G_CALLBACK (to_button_clicked_cb), mpage);
 		g_signal_connect ((priv->to_entry), "changed", G_CALLBACK (field_changed_cb), mpage);
 	}
-	
+
 	memo_page_set_show_categories (mpage, calendar_config_get_show_categories());
 
 	return TRUE;
@@ -1098,7 +1099,7 @@ get_to_entry (ENameSelector *name_selector)
 {
 	ENameSelectorModel *name_selector_model;
 	ENameSelectorEntry *name_selector_entry;
-	
+
 	name_selector_model = e_name_selector_peek_model (name_selector);
 	e_name_selector_model_add_section (name_selector_model, "To", _("To"), NULL);
 	name_selector_entry = (ENameSelectorEntry *)e_name_selector_peek_section_list (name_selector, "To");
@@ -1127,9 +1128,9 @@ memo_page_select_organizer (MemoPage *mpage, const char *backend_address)
 	if (source)
 		user_addr = e_source_get_property (source, "subscriber");
 
-	if (user_addr) 
+	if (user_addr)
 		subscribed_cal = TRUE;
-	else 
+	else
 		user_addr = backend_address;
 
 	priv->default_address = NULL;
@@ -1155,9 +1156,9 @@ memo_page_select_organizer (MemoPage *mpage, const char *backend_address)
 /**
  * memo_page_construct:
  * @mpage: An memo page.
- * 
+ *
  * Constructs an memo page by loading its Glade data.
- * 
+ *
  * Return value: The same object as @mpage, or NULL if the widgets could not be
  * created.
  **/
@@ -1212,7 +1213,7 @@ memo_page_construct (MemoPage *mpage)
 
 		gtk_widget_show (priv->org_label);
 		gtk_widget_show (priv->org_combo);
-		
+
 		if (flags & COMP_EDITOR_PAGE_NEW_ITEM) {
 			priv->name_selector = e_name_selector_new ();
 			priv->to_entry = get_to_entry (priv->name_selector);
@@ -1224,7 +1225,7 @@ memo_page_construct (MemoPage *mpage)
 	}
 
 	if (!init_widgets (mpage)) {
-		g_message ("memo_page_construct(): " 
+		g_message ("memo_page_construct(): "
 			   "Could not initialize the widgets!");
 		return NULL;
 	}
@@ -1234,9 +1235,9 @@ memo_page_construct (MemoPage *mpage)
 
 /**
  * memo_page_new:
- * 
+ *
  * Creates a new memo page.
- * 
+ *
  * Return value: A newly-created task page, or NULL if the page could
  * not be created.
  **/
