@@ -63,13 +63,13 @@ struct _TaskPagePrivate {
 
 	/* Bonobo Controller for the menu/toolbar */
 	BonoboUIComponent *uic;
-	
+
 	/* Widgets from the Glade file */
 	GtkWidget *main;
 
 	EAccountList *accounts;
 	GList *address_strings;
-	EMeetingAttendee *ia;	
+	EMeetingAttendee *ia;
 	char *default_address;
 	char *user_add;
 	ECalComponent *comp;
@@ -81,7 +81,7 @@ struct _TaskPagePrivate {
 
 	/* Lists of attendees */
 	GPtrArray *deleted_attendees;
-	
+
 	/* Generic informative messages placeholder */
 	GtkWidget *info_hbox;
 	GtkWidget *info_icon;
@@ -94,7 +94,7 @@ struct _TaskPagePrivate {
 	GtkWidget *start_date;
 	GtkWidget *timezone;
 	GtkWidget *timezone_label;
-	
+
 	GtkWidget *description;
 
 	ECalComponentClassification classification;
@@ -123,7 +123,7 @@ struct _TaskPagePrivate {
 	/* For handling who the organizer is */
 	gboolean user_org;
 	gboolean existing;
-	
+
 	gboolean updating;
 	gboolean sendoptions_shown;
 	gboolean is_assignment;
@@ -207,7 +207,7 @@ task_page_init (TaskPage *tpage)
 	priv->updating = FALSE;
 	priv->sendoptions_shown = FALSE;
 	priv->is_assignment = FALSE;
-	
+
 	priv->deleted_attendees = g_ptr_array_new ();
 
 	priv->comp = NULL;
@@ -217,16 +217,16 @@ task_page_init (TaskPage *tpage)
 	priv->ia = NULL;
 	priv->default_address = NULL;
 	priv->invite = NULL;
-	
+
 	priv->model = NULL;
-	priv->list_view = NULL;	
+	priv->list_view = NULL;
 }
 
 static void
 cleanup_attendees (GPtrArray *attendees)
 {
 	int i;
-	
+
 	for (i = 0; i < attendees->len; i++)
 		g_object_unref (g_ptr_array_index (attendees, i));
 }
@@ -256,7 +256,7 @@ task_page_finalize (GObject *object)
 		g_object_unref (priv->xml);
 		priv->xml = NULL;
 	}
-	
+
 	if (priv->sod) {
 		g_object_unref (priv->sod);
 		priv->sod = NULL;
@@ -264,7 +264,7 @@ task_page_finalize (GObject *object)
 
 	if (priv->comp != NULL)
 		g_object_unref (priv->comp);
- 
+
 	cleanup_attendees (priv->deleted_attendees);
 	g_ptr_array_free (priv->deleted_attendees, TRUE);
 
@@ -383,7 +383,7 @@ task_page_set_view_rsvp (TaskPage *page, gboolean state)
 	e_meeting_list_view_column_set_visible (priv->list_view, "RSVP", state);
 }
 
-void 
+void
 task_page_set_classification (TaskPage *page, ECalComponentClassification class)
 {
 	page->priv->classification = class;
@@ -394,19 +394,19 @@ sensitize_widgets (TaskPage *tpage)
 {
 	gboolean read_only, sens = TRUE, sensitize;
 	TaskPagePrivate *priv;
-	
+
 	priv = tpage->priv;
 
 	if (!e_cal_is_read_only (COMP_EDITOR_PAGE (tpage)->client, &read_only, NULL))
 		read_only = TRUE;
-	
+
 	if (COMP_EDITOR_PAGE (tpage)->flags & COMP_EDITOR_IS_ASSIGNED)
 	 	sens = COMP_EDITOR_PAGE (tpage)->flags & COMP_EDITOR_PAGE_USER_ORG;
 
 	sensitize = (!read_only && sens);
 
-	/* The list of organizers is set to be non-editable. Otherwise any 
-	 * change in the displayed list causes an 'Account not found' error. 
+	/* The list of organizers is set to be non-editable. Otherwise any
+	 * change in the displayed list causes an 'Account not found' error.
 	 */
 	gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (priv->organizer)->entry), FALSE);
 
@@ -424,7 +424,7 @@ sensitize_widgets (TaskPage *tpage)
 	e_meeting_list_view_set_editable (priv->list_view, (!read_only && sens));
 	gtk_widget_set_sensitive (priv->remove, (!read_only &&  sens));
 	gtk_widget_set_sensitive (priv->invite, (!read_only &&  sens));
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->list_view), !read_only);	
+	gtk_widget_set_sensitive (GTK_WIDGET (priv->list_view), !read_only);
 
 	bonobo_ui_component_set_prop (priv->uic, "/commands/InsertAttachments", "sensitive", sensitize ? "1" : "0"
 			, NULL);
@@ -443,21 +443,23 @@ sensitize_widgets (TaskPage *tpage)
 	bonobo_ui_component_set_prop (priv->uic, "/commands/OptionStatus", "sensitive", sensitize ? "1" : "0"
 			, NULL);
 
-	
+
 	if (!priv->is_assignment) {
 		gtk_widget_hide (priv->calendar_label);
 		gtk_widget_hide (priv->list_box);
 		gtk_widget_hide (priv->attendee_box);
 		gtk_widget_hide (priv->organizer);
 		gtk_widget_hide (priv->invite);
-		gtk_label_set_text_with_mnemonic ((GtkLabel *) priv->org_cal_label, _("_Group:"));
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->org_cal_label), _("_Group:"));
+		gtk_label_set_mnemonic_widget (GTK_LABEL (priv->org_cal_label), priv->source_selector);
 	} else {
-		gtk_widget_show (priv->invite);	
+		gtk_widget_show (priv->invite);
 		gtk_widget_show (priv->calendar_label);
 		gtk_widget_show (priv->list_box);
 		gtk_widget_show (priv->attendee_box);
 		gtk_widget_show (priv->organizer);
-		gtk_label_set_text_with_mnemonic ((GtkLabel *) priv->org_cal_label, _("Or_ganizer:"));		
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->org_cal_label), _("Organi_zer:"));
+		gtk_label_set_mnemonic_widget (GTK_LABEL (priv->org_cal_label), GTK_COMBO (priv->organizer)->entry);
 	}
 }
 void
@@ -468,13 +470,13 @@ task_page_hide_options (TaskPage *page)
 
 	bonobo_ui_component_set_prop (page->priv->uic, "/commands/InsertSendOptions", "hidden", "1", NULL);
 	page->priv->sendoptions_shown = FALSE;
-	
+
 }
 void
 task_page_show_options (TaskPage *page)
 {
 	g_return_if_fail (IS_TASK_PAGE (page));
-	
+
 	bonobo_ui_component_set_prop (page->priv->uic, "/commands/InsertSendOptions", "hidden", "0", NULL);
 	page->priv->sendoptions_shown = TRUE;
 }
@@ -490,17 +492,17 @@ task_page_set_assignment (TaskPage *page, gboolean set)
 
 static EAccount *
 get_current_account (TaskPage *page)
-{	
+{
 	TaskPagePrivate *priv;
 	EIterator *it;
 	const char *str;
-	
+
 	priv = page->priv;
 
 	str = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (priv->organizer)->entry));
 	if (!str)
 		return NULL;
-	
+
 	for (it = e_list_get_iterator((EList *)priv->accounts); e_iterator_is_valid(it); e_iterator_next(it)) {
 		EAccount *a = (EAccount *)e_iterator_get(it);
 		char *full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
@@ -511,12 +513,12 @@ get_current_account (TaskPage *page)
 
 			return a;
 		}
-	
+
 		g_free (full);
 	}
 	g_object_unref (it);
-	
-	return NULL;	
+
+	return NULL;
 }
 
 /* fill_widgets handler for the task page */
@@ -543,10 +545,10 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	if (priv->comp != NULL)
 		g_object_unref (priv->comp);
 	priv->comp = NULL;
-	
+
 	cleanup_attendees (priv->deleted_attendees);
 	g_ptr_array_set_size (priv->deleted_attendees, 0);
-	
+
 	/* Component for cancellation */
 	priv->comp = e_cal_component_clone (comp);
 
@@ -554,7 +556,7 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	clear_widgets (tpage);
 
 	priv->user_add = itip_get_comp_attendee (comp, page->client);
-	
+
         /* Summary, description(s) */
 	e_cal_component_get_summary (comp, &text);
 	e_dialog_editable_set (priv->summary, text.value);
@@ -562,7 +564,7 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	e_cal_component_get_description_list (comp, &l);
 	if (l && l->data) {
 		ECalComponentText *dtext;
-		
+
 		dtext = l->data;
 		gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->description)),
 					  dtext->value ? dtext->value : "", -1);
@@ -608,14 +610,14 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 			g_warning ("Couldn't get timezone from server: %s",
 				   d.tzid ? d.tzid : "");
 	}
-	
+
 	e_timezone_entry_set_timezone (E_TIMEZONE_ENTRY (priv->timezone),
 				       zone ? zone : default_zone);
 	task_page_set_show_timezone (tpage, calendar_config_get_show_timezone());
 
 	if (!(COMP_EDITOR_PAGE (tpage)->flags & COMP_EDITOR_PAGE_NEW_ITEM) && !zone) {
 			task_page_set_show_timezone (tpage, FALSE);
-			bonobo_ui_component_set_prop (priv->uic, "/commands/ViewTimeZone", 
+			bonobo_ui_component_set_prop (priv->uic, "/commands/ViewTimeZone",
 					"state", "0", NULL);
 	}
 
@@ -684,9 +686,9 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	set_subscriber_info_string (tpage, backend_addr);
 
 	if (priv->is_assignment) {
-		ECalComponentOrganizer organizer;	
-		
-		priv->user_add = itip_get_comp_attendee (comp, COMP_EDITOR_PAGE (tpage)->client);	
+		ECalComponentOrganizer organizer;
+
+		priv->user_add = itip_get_comp_attendee (comp, COMP_EDITOR_PAGE (tpage)->client);
 
 		/* Organizer strings */
 		task_page_select_organizer (tpage, backend_addr);
@@ -737,7 +739,7 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 				if (!(backend_addr && *backend_addr) || !g_ascii_strcasecmp (backend_addr, a->id->address)) {
 					e_meeting_attendee_set_address (priv->ia, g_strdup_printf ("MAILTO:%s", a->id->address));
 					e_meeting_attendee_set_cn (priv->ia, g_strdup (a->id->name));
-				} else { 
+				} else {
 					e_meeting_attendee_set_address (priv->ia, g_strdup_printf ("MAILTO:%s", backend_addr));
 					e_meeting_attendee_set_sentby (priv->ia, g_strdup_printf ("MAILTO:%s", a->id->address));
 				}
@@ -751,7 +753,7 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 		}
 	}
 
-	if (backend_addr) 
+	if (backend_addr)
 		g_free (backend_addr);
 
 	priv->updating = FALSE;
@@ -766,22 +768,22 @@ set_attendees (ECalComponent *comp, const GPtrArray *attendees)
 {
 	GSList *comp_attendees = NULL, *l;
 	int i;
-	
+
 	for (i = 0; i < attendees->len; i++) {
 		EMeetingAttendee *ia = g_ptr_array_index (attendees, i);
 		ECalComponentAttendee *ca;
-		
+
 		ca = e_meeting_attendee_as_e_cal_component_attendee (ia);
-		
+
 		comp_attendees = g_slist_prepend (comp_attendees, ca);
-		
+
 	}
 	comp_attendees = g_slist_reverse (comp_attendees);
-	
+
 	e_cal_component_set_attendee_list (comp, comp_attendees);
-	
+
 	for (l = comp_attendees; l != NULL; l = l->next)
-		g_free (l->data);	
+		g_free (l->data);
 	g_slist_free (comp_attendees);
 }
 
@@ -906,12 +908,12 @@ task_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 	} else {
 		e_cal_component_set_dtstart (comp, NULL);
 	}
-	
+
 	/* Classification. */
 	e_cal_component_set_classification (comp, priv->classification);
-	
+
 	/* send options */
-	if (priv->sendoptions_shown && priv->sod) 
+	if (priv->sendoptions_shown && priv->sod)
 		e_sendoptions_utils_fill_component (priv->sod, comp);
 
 	/* Categories */
@@ -939,16 +941,16 @@ task_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 
 			/* Sanity Check */
 			if (a == NULL) {
-				e_notice (page, GTK_MESSAGE_ERROR,
+				e_notice (priv->main, GTK_MESSAGE_ERROR,
 						_("The organizer selected no longer has an account."));
-				return FALSE;			
+				return FALSE;
 			}
 
 			if (a->id->address == NULL || strlen (a->id->address) == 0) {
-				e_notice (page, GTK_MESSAGE_ERROR,
+				e_notice (priv->main, GTK_MESSAGE_ERROR,
 						_("An organizer is required."));
 				return FALSE;
-			} 
+			}
 
 			if (!(backend_addr && *backend_addr) || !g_ascii_strcasecmp (backend_addr, a->id->address)) {
 				org_addr = g_strdup_printf ("MAILTO:%s", a->id->address);
@@ -969,7 +971,7 @@ task_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 		}
 
 		if (e_meeting_store_count_actual_attendees (priv->model) < 1) {
-			e_notice (page, GTK_MESSAGE_ERROR,
+			e_notice (priv->main, GTK_MESSAGE_ERROR,
 					_("At least one attendee is required."));
 			return FALSE;
 		}
@@ -1004,7 +1006,7 @@ task_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 			}
 			e_cal_component_set_attendee_list (comp, attendee_list);
 			e_cal_component_free_attendee_list (attendee_list);
-		} else 
+		} else
 			set_attendees (comp, e_meeting_store_get_attendees (priv->model));
 	}
 
@@ -1043,16 +1045,16 @@ static void edit_clicked_cb (GtkButton *btn, TaskPage *tpage)
 
 
 static gboolean
-existing_attendee (EMeetingAttendee *ia, ECalComponent *comp) 
+existing_attendee (EMeetingAttendee *ia, ECalComponent *comp)
 {
 	GSList *attendees, *l;
 	const gchar *ia_address;
 	const gchar *ia_sentby = NULL;
-	
+
 	ia_address = itip_strip_mailto (e_meeting_attendee_get_address (ia));
 	if (!ia_address)
 		return FALSE;
-	
+
 	if (e_meeting_attendee_is_set_sentby (ia))
 		ia_sentby = itip_strip_mailto (e_meeting_attendee_get_sentby (ia));
 
@@ -1062,7 +1064,7 @@ existing_attendee (EMeetingAttendee *ia, ECalComponent *comp)
 		ECalComponentAttendee *attendee = l->data;
 		const char *address;
 		const char *sentby = NULL;
-		
+
 		address = itip_strip_mailto (attendee->value);
 		if (attendee->sentby)
 			sentby = itip_strip_mailto (attendee->sentby);
@@ -1072,19 +1074,19 @@ existing_attendee (EMeetingAttendee *ia, ECalComponent *comp)
 			return TRUE;
 		}
 	}
-	
+
 	e_cal_component_free_attendee_list (attendees);
-	
+
 	return FALSE;
 }
 
 static void
-remove_attendee (TaskPage *page, EMeetingAttendee *ia) 
+remove_attendee (TaskPage *page, EMeetingAttendee *ia)
 {
 	TaskPagePrivate *priv;
 	int pos = 0;
 	gboolean delegate = (COMP_EDITOR_PAGE (page)->flags & COMP_EDITOR_PAGE_DELEGATE);
-	
+
 	priv = page->priv;
 
 	/* If the user deletes the organizer attendee explicitly,
@@ -1092,22 +1094,22 @@ remove_attendee (TaskPage *page, EMeetingAttendee *ia)
 	if (ia == priv->ia) {
 		g_object_unref (priv->ia);
 		priv->ia = NULL;
-	}	
-		
+	}
+
 	/* If this was a delegatee, no longer delegate */
 	if (e_meeting_attendee_is_set_delfrom (ia)) {
 		EMeetingAttendee *ib;
-		
+
 		ib = e_meeting_store_find_attendee (priv->model, e_meeting_attendee_get_delfrom (ia), &pos);
 		if (ib != NULL) {
 			e_meeting_attendee_set_delto (ib, NULL);
-			
-			if (!delegate) 
+
+			if (!delegate)
 				e_meeting_attendee_set_edit_level (ib,  E_MEETING_ATTENDEE_EDIT_FULL);
-		}		
+		}
 	}
-	
-	/* Handle deleting all attendees in the delegation chain */	
+
+	/* Handle deleting all attendees in the delegation chain */
 	while (ia != NULL) {
 		EMeetingAttendee *ib = NULL;
 
@@ -1115,14 +1117,16 @@ remove_attendee (TaskPage *page, EMeetingAttendee *ia)
 			g_object_ref (ia);
 			g_ptr_array_add (priv->deleted_attendees, ia);
 		}
-		
+
 		if (e_meeting_attendee_get_delto (ia) != NULL)
 			ib = e_meeting_store_find_attendee (priv->model, e_meeting_attendee_get_delto (ia), NULL);
+
+		e_meeting_list_view_remove_attendee_from_name_selector (priv->list_view, ia);
 		e_meeting_store_remove_attendee (priv->model, ia);
 
 		ia = ib;
 	}
-	
+
 	sensitize_widgets (page);
 }
 
@@ -1138,7 +1142,7 @@ remove_clicked_cb (GtkButton *btn, TaskPage *page)
 	GtkTreeModel *model = NULL;
 	gboolean valid_iter;
 	char *address;
-	
+
 	priv = page->priv;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->list_view));
@@ -1148,10 +1152,10 @@ remove_clicked_cb (GtkButton *btn, TaskPage *page)
 		return;
 	}
 	paths = g_list_reverse (paths);
-	
+
 	for (tmp = paths; tmp; tmp=tmp->next) {
 		path = tmp->data;
-		
+
 		gtk_tree_model_get_iter (GTK_TREE_MODEL(priv->model), &iter, path);
 
 		gtk_tree_model_get (GTK_TREE_MODEL (priv->model), &iter, E_MEETING_STORE_ADDRESS_COL, &address, -1);
@@ -1161,35 +1165,35 @@ remove_clicked_cb (GtkButton *btn, TaskPage *page)
 			g_warning ("Cannot delete attendee\n");
 			continue;
 		} else if (e_meeting_attendee_get_edit_level (ia) != E_MEETING_ATTENDEE_EDIT_FULL) {
-			g_warning("Not enough rights to delete attendee: %s\n", e_meeting_attendee_get_address(ia));	
+			g_warning("Not enough rights to delete attendee: %s\n", e_meeting_attendee_get_address(ia));
 			continue;
 		}
-		
+
 		remove_attendee (page, ia);
 	}
-	
+
 	/* Select closest item after removal */
 	valid_iter = gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path);
 	if (!valid_iter) {
 		gtk_tree_path_prev (path);
 		valid_iter = gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path);
 	}
-	
+
 	if (valid_iter) {
 		gtk_tree_selection_unselect_all (selection);
 		gtk_tree_selection_select_iter (selection, &iter);
 	}
-	
+
 	g_list_foreach (paths, (GFunc) gtk_tree_path_free, NULL);
 	g_list_free (paths);
 }
 
 static void
-invite_cb (GtkWidget *widget, gpointer data) 
+invite_cb (GtkWidget *widget, gpointer data)
 {
 	TaskPage *page;
 	TaskPagePrivate *priv;
-	
+
 	page = TASK_PAGE (data);
 	priv = page->priv;
 
@@ -1199,7 +1203,7 @@ invite_cb (GtkWidget *widget, gpointer data)
 static void
 attendee_added_cb (EMeetingListView *emlv, EMeetingAttendee *ia, gpointer user_data)
 {
-   TaskPage *page = TASK_PAGE (user_data);	
+   TaskPage *page = TASK_PAGE (user_data);
    TaskPagePrivate *priv;
    gboolean delegate = (COMP_EDITOR_PAGE (page)->flags & COMP_EDITOR_PAGE_DELEGATE);
 
@@ -1209,13 +1213,13 @@ attendee_added_cb (EMeetingListView *emlv, EMeetingAttendee *ia, gpointer user_d
 	   if (existing_attendee (ia, priv->comp))
 		   e_meeting_store_remove_attendee (priv->model, ia);
 	   else {
-		   if (!e_cal_get_static_capability (COMP_EDITOR_PAGE(page)->client, 
+		   if (!e_cal_get_static_capability (COMP_EDITOR_PAGE(page)->client,
 					   CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY)) {
 			   const char *delegator_id = e_meeting_attendee_get_delfrom (ia);
 			   EMeetingAttendee *delegator;
 
 			   delegator = e_meeting_store_find_attendee (priv->model, delegator_id, NULL);
-			   e_meeting_attendee_set_delto (delegator, 
+			   e_meeting_attendee_set_delto (delegator,
 					   g_strdup (e_meeting_attendee_get_address (ia)));
 
 			   gtk_widget_set_sensitive (priv->invite, FALSE);
@@ -1253,7 +1257,7 @@ enum {
 
 static EPopupItem context_menu_items[] = {
 	{ E_POPUP_ITEM, "10.delete", N_("_Remove"), popup_delete_cb, NULL, GTK_STOCK_REMOVE, ATTENDEE_CAN_DELETE },
-	{ E_POPUP_ITEM, "15.add", N_("_Add "), popup_add_cb, NULL, GTK_STOCK_ADD, ATTENDEE_CAN_ADD },	
+	{ E_POPUP_ITEM, "15.add", N_("_Add "), popup_add_cb, NULL, GTK_STOCK_ADD, ATTENDEE_CAN_ADD },
 };
 
 static void
@@ -1287,7 +1291,7 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, TaskPage *page)
 		GtkTreeSelection *selection;
 
 		if (gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path)) {
-		
+
 			gtk_tree_model_get (GTK_TREE_MODEL (priv->model), &iter, E_MEETING_STORE_ADDRESS_COL, &address, -1);
 			ia = e_meeting_store_find_attendee (priv->model, address, &priv->row);
 			g_free (address);
@@ -1296,7 +1300,7 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, TaskPage *page)
 				selection = gtk_tree_view_get_selection ((GtkTreeView *) priv->list_view);
 				gtk_tree_selection_unselect_all (selection);
 				gtk_tree_selection_select_path (selection, path);
-		
+
  				if (e_meeting_attendee_get_edit_level (ia) == E_MEETING_ATTENDEE_EDIT_FULL)
  					disable_mask &= ~ATTENDEE_CAN_DELETE;
 			}
@@ -1312,7 +1316,7 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, TaskPage *page)
 
 	for (i=0;i<sizeof(context_menu_items)/sizeof(context_menu_items[0]);i++)
 		menus = g_slist_prepend(menus, &context_menu_items[i]);
-	
+
 	e_popup_add_items((EPopup *)ep, menus, NULL, context_popup_free, page);
 	menu = e_popup_create_menu_once((EPopup *)ep, NULL, disable_mask);
 	gtk_menu_popup (menu, NULL, NULL, NULL, NULL, event->button, event->time);
@@ -1322,9 +1326,9 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, TaskPage *page)
 
 static gboolean
 list_view_event (EMeetingListView *list_view, GdkEvent *event, TaskPage *page) {
-	
+
 	TaskPagePrivate *priv= page->priv;
-	
+
 	if (event->type == GDK_2BUTTON_PRESS && COMP_EDITOR_PAGE (page)->flags & COMP_EDITOR_PAGE_USER_ORG) {
 		EMeetingAttendee *attendee;
 
@@ -1338,7 +1342,7 @@ list_view_event (EMeetingListView *list_view, GdkEvent *event, TaskPage *page) {
 		return TRUE;
 	}
 
-	return FALSE;	
+	return FALSE;
 }
 
 
@@ -1346,7 +1350,7 @@ static gboolean
 list_key_press (EMeetingListView *list_view, GdkEventKey *event, TaskPage *page)
 {
 	if (event->keyval == GDK_Delete) {
-	
+
 		remove_clicked_cb (NULL, page);
 
 		return TRUE;
@@ -1359,17 +1363,17 @@ list_key_press (EMeetingListView *list_view, GdkEventKey *event, TaskPage *page)
 	return FALSE;
 }
 
-void 
+void
 task_page_set_show_timezone (TaskPage *page, gboolean state)
 {
 	if (state) {
 		gtk_widget_show_all (page->priv->timezone);
-		gtk_widget_show (page->priv->timezone_label);	
+		gtk_widget_show (page->priv->timezone_label);
 	} else {
 		gtk_widget_hide (page->priv->timezone);
 		gtk_widget_hide (page->priv->timezone_label);
 	}
-		
+
 }
 
 void
@@ -1377,7 +1381,7 @@ task_page_set_show_categories (TaskPage *page, gboolean state)
 {
 	if (state) {
 		gtk_widget_show (page->priv->categories_btn);
-		gtk_widget_show (page->priv->categories);	
+		gtk_widget_show (page->priv->categories);
 	} else {
 		gtk_widget_hide (page->priv->categories_btn);
 		gtk_widget_hide (page->priv->categories);
@@ -1406,7 +1410,7 @@ task_page_fill_timezones (CompEditorPage *page, GHashTable *timezones)
 }
 
 /*If the msg has some value set, the icon should always be set */
-void 
+void
 task_page_set_info_string (TaskPage *tpage, const gchar *icon, const gchar *msg)
 {
 	TaskPagePrivate *priv;
@@ -1417,9 +1421,9 @@ task_page_set_info_string (TaskPage *tpage, const gchar *icon, const gchar *msg)
 	gtk_label_set_text (GTK_LABEL(priv->info_string), msg);
 
 	if (msg && icon)
-		gtk_widget_show (priv->info_hbox); 
+		gtk_widget_show (priv->info_hbox);
 	else
-		gtk_widget_hide (priv->info_hbox); 
+		gtk_widget_hide (priv->info_hbox);
 }
 
 /* set_summary handler for the task page */
@@ -1503,7 +1507,7 @@ get_widgets (TaskPage *tpage)
 	priv->org_cal_label = GW ("org-task-label");
 
 	priv->list_view = e_meeting_list_view_new (priv->model);
-	
+
 	selection = gtk_tree_view_get_selection ((GtkTreeView *) priv->list_view);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 	gtk_widget_show (GTK_WIDGET (priv->list_view));
@@ -1516,7 +1520,9 @@ get_widgets (TaskPage *tpage)
 	gtk_box_pack_start (GTK_BOX (priv->list_box), sw, TRUE, TRUE, 0);
 
 	priv->source_selector = GW ("source");
-	
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->calendar_label), priv->source_selector);
+
 #undef GW
 
 	return (priv->summary
@@ -1527,6 +1533,7 @@ get_widgets (TaskPage *tpage)
 		&& priv->description
 		&& priv->categories_btn
 		&& priv->categories
+		&& priv->organizer
 		);
 }
 
@@ -1537,21 +1544,21 @@ summary_changed_cb (GtkEditable *editable, gpointer data)
 	TaskPage *tpage;
 	TaskPagePrivate *priv;
 	gchar *summary;
-	
+
 	tpage = TASK_PAGE (data);
 	priv = tpage->priv;
-	
+
 	if (priv->updating)
 		return;
-	
+
 	summary = e_dialog_editable_get (GTK_WIDGET (editable));
-	comp_editor_page_notify_summary_changed (COMP_EDITOR_PAGE (tpage), 
+	comp_editor_page_notify_summary_changed (COMP_EDITOR_PAGE (tpage),
 						 summary);
 	g_free (summary);
 }
 
 /* Callback used when the start or due date widgets change.  We notify the
- * other pages in the task editor, so they can update any labels. 
+ * other pages in the task editor, so they can update any labels.
  */
 static void
 date_changed_cb (EDateEdit *dedit, gpointer data)
@@ -1616,7 +1623,7 @@ date_changed_cb (EDateEdit *dedit, gpointer data)
 	due_dt.value = &due_tt;
 	dates.due = &due_dt;
 	dates.complete = NULL;
-	
+
 	/* Notify upstream */
 	comp_editor_page_notify_dates_changed (COMP_EDITOR_PAGE (tpage),
 					       &dates);
@@ -1627,7 +1634,7 @@ timezone_changed_cb (EDateEdit *dedit, gpointer data)
 {
 	TaskPage *tpage;
 	TaskPagePrivate *priv;
-	
+
 	tpage = TASK_PAGE (data);
 	priv = tpage->priv;
 
@@ -1652,7 +1659,7 @@ categories_clicked_cb (GtkWidget *button, gpointer data)
 	e_categories_config_open_dialog_for_entry (GTK_ENTRY (entry));
 }
 /* sets the current focused widget */
-static gboolean 
+static gboolean
 widget_focus_in_cb (GtkWidget *widget,  GdkEventFocus *event, gpointer data)
 {
 	TaskPage *tpage;
@@ -1679,10 +1686,10 @@ field_changed_cb (GtkWidget *widget, gpointer data)
 {
 	TaskPage *tpage;
 	TaskPagePrivate *priv;
-	
+
 	tpage = TASK_PAGE (data);
 	priv = tpage->priv;
-	
+
 	if (!priv->updating)
 		comp_editor_page_notify_changed (COMP_EDITOR_PAGE (tpage));
 }
@@ -1746,7 +1753,7 @@ times_updated (TaskPage *tpage, gboolean adjust_end_time)
 	gboolean date_set;
 	gboolean set_start_date = FALSE, set_end_date = FALSE, adjust_by_hour;
 	icaltimezone *zone;
-	
+
 	priv = tpage->priv;
 
 	if (priv->updating)
@@ -1851,11 +1858,11 @@ source_changed_cb (ESourceComboBox *source_combo_box, TaskPage *tpage)
 		client = auth_new_cal_from_source (source, E_CAL_SOURCE_TYPE_TODO);
 		if (client) {
 			icaltimezone *zone;
-			
+
 			zone = calendar_config_get_icaltimezone ();
 			e_cal_set_default_timezone (client, zone, NULL);
 		}
-		
+
 		if (!client || !e_cal_open (client, FALSE, NULL)) {
 			GtkWidget *dialog;
 
@@ -1886,7 +1893,7 @@ source_changed_cb (ESourceComboBox *source_combo_box, TaskPage *tpage)
 				gchar *backend_addr = NULL;
 
 				e_cal_get_cal_address(client, &backend_addr, NULL);
-				
+
 				if (priv->is_assignment)
 					task_page_select_organizer (tpage, backend_addr);
 
@@ -1904,13 +1911,13 @@ set_subscriber_info_string (TaskPage *tpage, const char *backend_address)
 {
 	ECal *client = COMP_EDITOR_PAGE (tpage)->client;
 	ESource *source;
-	
+
 	source = e_cal_get_source (client);
-	
+
 	if (e_source_get_property (source, "subscriber"))
-		/* Translators: This string is used when we are creating a Task 
+		/* Translators: This string is used when we are creating a Task
 		   on behalf of some other user */
-		task_page_set_info_string (tpage, GTK_STOCK_DIALOG_INFO, 
+		task_page_set_info_string (tpage, GTK_STOCK_DIALOG_INFO,
 				g_strdup_printf(_("You are acting on behalf of %s"), backend_address));
 	else
 		task_page_set_info_string (tpage, NULL, NULL);
@@ -1924,7 +1931,7 @@ task_page_sendoptions_clicked_cb (TaskPage *tpage)
 	ESource *source;
 
 	priv = tpage->priv;
-	
+
 	if (!priv->sod) {
 		priv->sod = e_sendoptions_dialog_new ();
 		priv->sod->data->initialized = TRUE;
@@ -1932,12 +1939,12 @@ task_page_sendoptions_clicked_cb (TaskPage *tpage)
 			E_SOURCE_COMBO_BOX (priv->source_selector));
 		e_sendoptions_utils_set_default_data (priv->sod, source, "task");
 	}
-	
-	if (e_cal_get_static_capability (COMP_EDITOR_PAGE (tpage)->client, 
+
+	if (e_cal_get_static_capability (COMP_EDITOR_PAGE (tpage)->client,
 					 CAL_STATIC_CAPABILITY_NO_GEN_OPTIONS)) {
 		e_sendoptions_set_need_general_options (priv->sod, FALSE);
 	}
-	
+
 	toplevel = gtk_widget_get_toplevel (priv->main);
 	e_sendoptions_dialog_run (priv->sod, toplevel, E_ITEM_TASK);
 }
@@ -1960,7 +1967,7 @@ init_widgets (TaskPage *tpage)
 	e_date_edit_set_get_time_callback (E_DATE_EDIT (priv->due_date),
 					   (EDateEditGetTimeCallback) comp_editor_get_current_time,
 					   tpage, NULL);
-	
+
 	/* Generic informative messages */
 	gtk_widget_hide (priv->info_hbox);
 
@@ -1985,7 +1992,7 @@ init_widgets (TaskPage *tpage)
 	/* Categories button */
 	g_signal_connect((priv->categories_btn), "clicked",
 			    G_CALLBACK (categories_clicked_cb), tpage);
-	
+
 	/* Source selector */
 	g_signal_connect (priv->source_selector, "changed", G_CALLBACK (source_changed_cb), tpage);
 
@@ -2020,8 +2027,8 @@ init_widgets (TaskPage *tpage)
 			    G_CALLBACK (field_changed_cb), tpage);
 	g_signal_connect (G_OBJECT (priv->list_view), "button_press_event", G_CALLBACK (button_press_event), tpage);
 	g_signal_connect (G_OBJECT (priv->list_view), "event", G_CALLBACK (list_view_event), tpage);
-	g_signal_connect (priv->list_view, "key_press_event", G_CALLBACK (list_key_press), tpage);	
-	
+	g_signal_connect (priv->list_view, "key_press_event", G_CALLBACK (list_key_press), tpage);
+
 	/* Add attendee button */
 	g_signal_connect (priv->add, "clicked", G_CALLBACK (add_clicked_cb), tpage);
 
@@ -2032,24 +2039,24 @@ init_widgets (TaskPage *tpage)
 	g_signal_connect (priv->remove, "clicked", G_CALLBACK (remove_clicked_cb), tpage);
 
 	/* Contacts button */
-	g_signal_connect(priv->invite, "clicked", G_CALLBACK (invite_cb), tpage);	
+	g_signal_connect(priv->invite, "clicked", G_CALLBACK (invite_cb), tpage);
 
 	/* Meeting List View */
-	g_signal_connect (priv->list_view, "attendee_added", G_CALLBACK (attendee_added_cb), tpage);	
-	
+	g_signal_connect (priv->list_view, "attendee_added", G_CALLBACK (attendee_added_cb), tpage);
+
 	/* Set the default timezone, so the timezone entry may be hidden. */
 	zone = calendar_config_get_icaltimezone ();
 	e_timezone_entry_set_default_timezone (E_TIMEZONE_ENTRY (priv->timezone), zone);
-	
+
 	task_page_set_show_timezone (tpage, calendar_config_get_show_timezone());
 
-	e_meeting_list_view_column_set_visible (priv->list_view, "Attendee                          ", 
+	e_meeting_list_view_column_set_visible (priv->list_view, "Attendee                          ",
 			TRUE);
 	e_meeting_list_view_column_set_visible (priv->list_view, "Role", calendar_config_get_show_role());
 	e_meeting_list_view_column_set_visible (priv->list_view, "RSVP", calendar_config_get_show_rsvp());
 	e_meeting_list_view_column_set_visible (priv->list_view, "Status", calendar_config_get_show_status());
 	e_meeting_list_view_column_set_visible (priv->list_view, "Type", calendar_config_get_show_type());
-	
+
 	task_page_set_show_categories (tpage, calendar_config_get_show_categories());
 
 	return TRUE;
@@ -2080,7 +2087,7 @@ task_page_select_organizer (TaskPage *tpage, const char *backend_address)
 
 	if (user_addr)
 		subscribed_cal = TRUE;
-	else 
+	else
 		user_addr = (backend_address && *backend_address) ? backend_address : NULL;
 
 	priv->default_address = NULL;
@@ -2107,9 +2114,9 @@ task_page_select_organizer (TaskPage *tpage, const char *backend_address)
 /**
  * task_page_construct:
  * @tpage: An task page.
- * 
+ *
  * Constructs an task page by loading its Glade data.
- * 
+ *
  * Return value: The same object as @tpage, or NULL if the widgets could not be
  * created.
  **/
@@ -2120,7 +2127,7 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 	EIterator *it;
 	EAccount *a;
 	char *gladefile;
-	
+
 	priv = tpage->priv;
 	g_object_ref (model);
 	priv->model = model;
@@ -2149,7 +2156,7 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 	     e_iterator_is_valid(it);
 	     e_iterator_next(it)) {
 		gchar *full = NULL;
-		
+
 		a = (EAccount *)e_iterator_get(it);
 
 		if (!a->enabled)
@@ -2159,7 +2166,7 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 
 		priv->address_strings = g_list_append(priv->address_strings, full);
 	}
-	
+
 	g_object_unref(it);
 
 	if (priv->address_strings)
@@ -2168,7 +2175,7 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 		g_warning ("No potential organizers!");
 
 	if (!init_widgets (tpage)) {
-		g_message ("task_page_construct(): " 
+		g_message ("task_page_construct(): "
 			   "Could not initialize the widgets!");
 		return NULL;
 	}
@@ -2178,9 +2185,9 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 
 /**
  * task_page_new:
- * 
+ *
  * Creates a new task page.
- * 
+ *
  * Return value: A newly-created task page, or NULL if the page could
  * not be created.
  **/
@@ -2194,7 +2201,7 @@ task_page_new (EMeetingStore *model, ECal *client, BonoboUIComponent *uic)
 		g_object_unref (tpage);
 		return NULL;
 	}
-	
+
 	tpage->priv->uic = uic;
 
 	return tpage;
@@ -2212,9 +2219,9 @@ task_page_get_cancel_comp (TaskPage *page)
 
 	if (priv->deleted_attendees->len == 0)
 		return NULL;
-	
+
 	set_attendees (priv->comp, priv->deleted_attendees);
-	
+
 	return e_cal_component_clone (priv->comp);
 }
 
@@ -2251,3 +2258,23 @@ task_page_create_source_combo_box (void)
 	gtk_widget_show (combo_box);
 	return combo_box;
 }
+
+/**
+ * task_page_add_attendee
+ * Add attendee to meeting store and name selector.
+ * @param tpage TaskPage.
+ * @param attendee Attendee to be added.
+ **/
+void
+task_page_add_attendee (TaskPage *tpage, EMeetingAttendee *attendee)
+{
+	TaskPagePrivate *priv;
+
+	g_return_if_fail (tpage != NULL);
+	g_return_if_fail (IS_TASK_PAGE (tpage));
+	
+	priv = tpage->priv;
+
+	e_meeting_store_add_attendee (priv->model, attendee);
+	e_meeting_list_view_add_attendee_to_name_selector (E_MEETING_LIST_VIEW (priv->list_view), attendee);
+}
