@@ -221,7 +221,7 @@ priority_compare_cb (gconstpointer a, gconstpointer b)
 }
 
 static void
-row_appended_cb (ECalModel *model, ECalendarTable *cal_table) 
+row_appended_cb (ECalModel *model, ECalendarTable *cal_table)
 {
 	g_signal_emit (cal_table, signals[USER_CREATED], 0);
 }
@@ -481,9 +481,9 @@ e_calendar_table_new (void)
 /**
  * e_calendar_table_get_model:
  * @cal_table: A calendar table.
- * 
+ *
  * Queries the calendar data model that a calendar table is using.
- * 
+ *
  * Return value: A calendar model.
  **/
 ECalModel *
@@ -514,9 +514,9 @@ e_calendar_table_destroy (GtkObject *object)
 /**
  * e_calendar_table_get_table:
  * @cal_table: A calendar table.
- * 
+ *
  * Queries the #ETable widget that the calendar table is using.
- * 
+ *
  * Return value: The #ETable widget that the calendar table uses to display its
  * data.
  **/
@@ -544,7 +544,7 @@ e_calendar_table_open_selected (ECalendarTable *cal_table)
 /**
  * e_calendar_table_complete_selected:
  * @cal_table: A calendar table
- * 
+ *
  * Marks the selected items as completed
  **/
 void
@@ -637,8 +637,8 @@ delete_selected_components (ECalendarTable *cal_table)
 	for (l = objs; l; l = l->next) {
 		ECalModelComponent *comp_data = (ECalModelComponent *) l->data;
 		GError *error = NULL;
-		
-		e_cal_remove_object (comp_data->client, 
+
+		e_cal_remove_object (comp_data->client,
 				     icalcomponent_get_uid (comp_data->icalcomp), &error);
 		delete_error_dialog (error, E_CAL_COMPONENT_TODO);
 		g_clear_error (&error);
@@ -663,7 +663,7 @@ add_retract_data (ECalComponent *comp, const char *retract_comment)
 	icalcomponent_add_property (icalcomp, icalprop);
 }
 
-static gboolean 
+static gboolean
 check_for_retract (ECalComponent *comp, ECal *client)
 {
 	ECalComponentOrganizer org;
@@ -671,13 +671,13 @@ check_for_retract (ECalComponent *comp, ECal *client)
 	const char *strip = NULL;
 	gboolean ret_val = FALSE;
 
-	if (!(e_cal_component_has_attendees (comp) && 
+	if (!(e_cal_component_has_attendees (comp) &&
 				e_cal_get_save_schedules (client)))
 		return ret_val;
 
 	e_cal_component_get_organizer (comp, &org);
 	strip = itip_strip_mailto (org.value);
-	
+
 	if (e_cal_get_cal_address (client, &email, NULL) && !g_ascii_strcasecmp (email, strip)) {
 		ret_val = TRUE;
 	}
@@ -692,7 +692,7 @@ check_for_retract (ECalComponent *comp, ECal *client)
 /**
  * e_calendar_table_delete_selected:
  * @cal_table: A calendar table.
- * 
+ *
  * Deletes the selected components in the table; asks the user first.
  **/
 void
@@ -725,7 +725,7 @@ e_calendar_table_delete_selected (ECalendarTable *cal_table)
 		comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
 	}
-	
+
 	if ((n_selected == 1) && comp && check_for_retract (comp, comp_data->client)) {
 		char *retract_comment = NULL;
 		gboolean retract = FALSE;
@@ -739,7 +739,7 @@ e_calendar_table_delete_selected (ECalendarTable *cal_table)
 			add_retract_data (comp, retract_comment);
 			icalcomp = e_cal_component_get_icalcomponent (comp);
 			icalcomponent_set_method (icalcomp, ICAL_METHOD_CANCEL);
-			if (!e_cal_send_objects (comp_data->client, icalcomp, &users, 
+			if (!e_cal_send_objects (comp_data->client, icalcomp, &users,
 						&mod_comp, &error))	{
 				delete_error_dialog (error, E_CAL_COMPONENT_TODO);
 				g_clear_error (&error);
@@ -770,10 +770,10 @@ e_calendar_table_delete_selected (ECalendarTable *cal_table)
 
 /**
  * e_calendar_table_get_selected:
- * @cal_table: 
- * 
+ * @cal_table:
+ *
  * Get the currently selected ECalModelComponent's on the table.
- * 
+ *
  * Return value: A GSList of the components, which should be
  * g_slist_free'd when finished with.
  **/
@@ -860,7 +860,7 @@ e_calendar_table_copy_clipboard (ECalendarTable *cal_table)
 	ETable *etable;
 	GtkClipboard *clipboard;
 	char *comp_str;
-	
+
 	g_return_if_fail (E_IS_CALENDAR_TABLE (cal_table));
 
 	/* create temporary VCALENDAR object */
@@ -877,7 +877,7 @@ e_calendar_table_copy_clipboard (ECalendarTable *cal_table)
 	} else {
 		gtk_clipboard_set_can_store (clipboard, target_types + 1, n_target_types - 1);
 	}
-	
+
 	/* free memory */
 	icalcomponent_free (cal_table->tmp_vcal);
 	cal_table->tmp_vcal = NULL;
@@ -911,7 +911,7 @@ clipboard_get_calendar_data (ECalendarTable *cal_table, const gchar *text)
 	}
 
 	client = e_cal_model_get_default_client (cal_table->model);
-	
+
 	e_calendar_table_set_status_message (cal_table, _("Updating objects"), -1);
 
 	if (kind == ICAL_VCALENDAR_COMPONENT) {
@@ -965,7 +965,7 @@ clipboard_paste_received_cb (GtkClipboard *clipboard,
 			     GtkSelectionData *selection_data,
 			     gpointer data)
 {
-	ECalendarTable *cal_table = E_CALENDAR_TABLE (data); 
+	ECalendarTable *cal_table = E_CALENDAR_TABLE (data);
 	ETable *e_table = e_table_scrolled_get_table (E_TABLE_SCROLLED (cal_table->etable));
 	GnomeCanvas *canvas = e_table->table_canvas;
 	GnomeCanvasItem *item = GNOME_CANVAS (canvas)->focused_item;
@@ -1018,7 +1018,7 @@ e_calendar_table_open_task (ECalendarTable *cal_table, ECal *client, icalcompone
 	CompEditor *tedit;
 	const char *uid;
 	guint32 flags = 0;
-	
+
 	uid = icalcomponent_get_uid (icalcomp);
 
 	tedit = e_comp_editor_registry_find (comp_editor_registry, uid);
@@ -1031,17 +1031,17 @@ e_calendar_table_open_task (ECalendarTable *cal_table, ECal *client, icalcompone
 		if (assign) {
 			flags |= COMP_EDITOR_IS_ASSIGNED;
 
-			if (itip_organizer_is_user (comp, client) || 
+			if (itip_organizer_is_user (comp, client) ||
 					!e_cal_component_has_attendees (comp))
 				flags |= COMP_EDITOR_USER_ORG;
 		}
 
 		tedit = COMP_EDITOR (task_editor_new (client, flags));
 		comp_editor_edit_comp (tedit, comp);
-	
+
 		if (flags & COMP_EDITOR_IS_ASSIGNED)
 			task_editor_show_assignment (TASK_EDITOR (tedit));
-		
+
 		e_comp_editor_registry_add (comp_editor_registry, tedit, FALSE);
 	}
 	comp_editor_focus (tedit);
@@ -1061,7 +1061,7 @@ open_task_by_row (ECalendarTable *cal_table, int row)
 
 static void
 e_calendar_table_on_double_click (ETable *table,
-				  gint row, 
+				  gint row,
 				  gint col,
 				  GdkEvent *event,
 				  ECalendarTable *cal_table)
@@ -1091,15 +1091,15 @@ e_calendar_table_on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 	ECalModelComponent *comp_data;
 	char *filename;
 	char *ical_string;
-	
+
 	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	if (comp_data == NULL)
 		return;
-	
+
 	filename = e_file_dialog_save (_("Save as..."), NULL);
 	if (filename == NULL)
 		return;
-	
+
 	ical_string = e_cal_get_component_as_string (comp_data->client, comp_data->icalcomp);
 	if (ical_string == NULL) {
 		g_warning ("Couldn't convert item to a string");
@@ -1107,7 +1107,7 @@ e_calendar_table_on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 	}
 
 	e_write_file_uri (filename, ical_string);
-	
+
 	g_free (ical_string);
 }
 
@@ -1121,7 +1121,7 @@ e_calendar_table_on_print_task (EPopup *ep, EPopupItem *pitem, void *data)
 	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	if (comp_data == NULL)
 		return;
-	
+
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
 	print_comp (comp, comp_data->client, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG);
@@ -1306,7 +1306,7 @@ on_new_task (EPopup *ep, EPopupItem *pitem, void *data)
 		return;
 
 	e_tasks_new_task (tasks);
-	
+
 }
 
 /* Callback for the "delete tasks" menu item */
@@ -1321,14 +1321,14 @@ delete_cb (EPopup *ep, EPopupItem *pitem, void *data)
 static EPopupItem tasks_popup_items [] = {
 	{ E_POPUP_ITEM, "00.newtask", N_("New _Task"), on_new_task, NULL, "stock_task", 0, 0},
 	{ E_POPUP_BAR, "01.bar" },
-	
+
 	{ E_POPUP_ITEM, "03.open", N_("_Open"), e_calendar_table_on_open_task, NULL, GTK_STOCK_OPEN, E_CAL_POPUP_SELECT_ONE },
 	{ E_POPUP_ITEM, "05.openweb", N_("Open _Web Page"), open_url_cb, NULL, NULL, E_CAL_POPUP_SELECT_ONE, E_CAL_POPUP_SELECT_HASURL },
 	{ E_POPUP_ITEM, "10.saveas", N_("_Save As..."), e_calendar_table_on_save_as, NULL, GTK_STOCK_SAVE_AS, E_CAL_POPUP_SELECT_ONE },
 	{ E_POPUP_ITEM, "20.print", N_("_Print..."), e_calendar_table_on_print_task, NULL, GTK_STOCK_PRINT, E_CAL_POPUP_SELECT_ONE },
 
 	{ E_POPUP_BAR, "30.bar" },
-	
+
 	{ E_POPUP_ITEM, "40.cut", N_("C_ut"), e_calendar_table_on_cut, NULL, GTK_STOCK_CUT, 0, E_CAL_POPUP_SELECT_EDITABLE },
 	{ E_POPUP_ITEM, "50.copy", N_("_Copy"), e_calendar_table_on_copy, NULL, GTK_STOCK_COPY, 0, 0 },
 	{ E_POPUP_ITEM, "60.paste", N_("_Paste"), e_calendar_table_on_paste, NULL, GTK_STOCK_PASTE, 0, E_CAL_POPUP_SELECT_EDITABLE },
@@ -1432,7 +1432,7 @@ e_calendar_table_on_key_press (ETable *table,
 	} else if ((event->keyval == GDK_o)
 		   &&(event->state & GDK_CONTROL_MASK)) {
 		open_task_by_row (cal_table, row);
-		return TRUE;	
+		return TRUE;
 	}
 
 	return FALSE;
@@ -1476,6 +1476,9 @@ hide_completed_rows (ECalModel *model, GList *clients_list, char *hide_sexp, GPt
 
 		g_list_foreach (objects, (GFunc) icalcomponent_free, NULL);
 		g_list_free (objects);
+
+		/* to notify about changes, because in call of row_deleted there are still all events */
+		e_table_model_changed (E_TABLE_MODEL (model));
 	}
 }
 
@@ -1514,7 +1517,7 @@ show_completed_rows (ECalModel *model, GList *clients_list, char *show_sexp, GPt
 
 				g_ptr_array_add (comp_objects, comp_data);
 				e_table_model_row_inserted (E_TABLE_MODEL (model), comp_objects->len - 1);
-			} 
+			}
 			e_cal_component_free_id (id);
 			g_object_unref (comp);
 		}
@@ -1603,7 +1606,7 @@ e_calendar_table_set_status_message (ECalendarTable *cal_table, const gchar *mes
 
 	if (!cal_table->activity_handler)
 		return;
-	
+
         if (!message || !*message) {
 		if (cal_table->activity_id != 0) {
 			e_activity_handler_operation_finished (cal_table->activity_handler, cal_table->activity_id);
@@ -1611,7 +1614,7 @@ e_calendar_table_set_status_message (ECalendarTable *cal_table, const gchar *mes
 		}
         } else if (cal_table->activity_id == 0) {
                 char *client_id = g_strdup_printf ("%p", cal_table);
-		
+
                 if (progress_icon == NULL)
                         progress_icon = e_icon_factory_get_icon (EVOLUTION_TASKS_PROGRESS_IMAGE, E_ICON_SIZE_STATUS);
 
@@ -1620,9 +1623,9 @@ e_calendar_table_set_status_message (ECalendarTable *cal_table, const gchar *mes
 
                 g_free (client_id);
         } else {
-		
+
 		double progress;
-		
+
 		if (percent < 0)
 			progress = -1.0;
 		else {
@@ -1653,7 +1656,7 @@ e_calendar_table_process_completed_tasks (ECalendarTable *table, GList *clients_
 
 	g_mutex_lock (mutex);
 
-	model = e_calendar_table_get_model (table); 
+	model = e_calendar_table_get_model (table);
 	comp_objects = e_cal_model_get_object_array (model);
 
 	hide_sexp = calendar_config_get_hide_completed_tasks_sexp (TRUE);
