@@ -91,7 +91,7 @@ void emla_list_action (EPlugin *item, EMMenuTargetSelect* sel, EmlaAction action
 	mail_get_message (sel->folder, (const char*) g_ptr_array_index (sel->uids, 0),
 	                  emla_list_action_do, data, mail_thread_new);
 }
-	
+
 void emla_list_action_do (CamelFolder *folder, const char *uid, CamelMimeMessage *msg, void *data)
 {
 	emla_action_data *action_data = (emla_action_data *) data;
@@ -99,11 +99,13 @@ void emla_list_action_do (CamelFolder *folder, const char *uid, CamelMimeMessage
 	const char* header = NULL, *headerpos;
 	char *end, *url = NULL;
 	int t;
-	GError *err;
 	EMsgComposer *composer;
 	int send_message_response;
 	EAccount *account;
 
+	if (msg == NULL)
+		return;
+
 	for (t = 0; t < emla_n_action_headers; t++) {
 		if (emla_action_headers[t].action == action &&
 		    (header = camel_medium_get_header (CAMEL_MEDIUM (msg), emla_action_headers[t].header)) != NULL)
@@ -125,7 +127,7 @@ void emla_list_action_do (CamelFolder *folder, const char *uid, CamelMimeMessage
 			goto exit;
 		}
 	}
-	
+
 	/* parse the action value */
 	while (*headerpos) {
 		/* skip whitespace */
@@ -134,7 +136,7 @@ void emla_list_action_do (CamelFolder *folder, const char *uid, CamelMimeMessage
 			e_error_run (NULL, "org.gnome.mailing-list-actions:malformed-header", emla_action_headers[t].header, header, NULL);
 			goto exit;
 		}
-		
+
 		/* get URL portion */
 		url = g_strndup(headerpos, end - headerpos);
 
@@ -148,7 +150,7 @@ void emla_list_action_do (CamelFolder *folder, const char *uid, CamelMimeMessage
 				/* directly send message */
 				composer = e_msg_composer_new_from_url (url);
 				if ((account = mail_config_get_account_by_source_url (action_data->uri)))
-					e_msg_composer_hdrs_set_from_account ((EMsgComposerHdrs *) composer->hdrs, account->name);
+					e_msg_composer_hdrs_set_from_account (e_msg_composer_get_hdrs(composer), account->name);
 				em_utils_composer_send_cb (composer, NULL);
 			} else if (send_message_response == GTK_RESPONSE_NO) {
 				/* show composer */
@@ -157,26 +159,26 @@ void emla_list_action_do (CamelFolder *folder, const char *uid, CamelMimeMessage
 
 			goto exit;
 		} else {
-			err = NULL;
+			GError *err = NULL;
 			gnome_url_show (url, &err);
 			if (!err)
 				goto exit;
-			g_error_free (err);			
+			g_error_free (err);
 		}
 		g_free (url);
 		url = NULL;
 		headerpos = end++;
-		
+
 		/* ignore everything 'till next comma */
 		headerpos = strchr (headerpos, ',');
 		if (!headerpos)
 			break;
 		headerpos++;
 	}
-	
+
 	/* if we got here, there's no valid action */
 	e_error_run (NULL, "org.gnome.mailing-list-actions:no-action", header, NULL);
-	
+
 exit:
 	free (action_data->uri);
 	free (action_data);
