@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Ettore Perazzoli <ettore@ximian.com>
  */
@@ -26,8 +26,6 @@
 
 #include "e-multi-config-dialog.h"
 
-#include "e-clipped-label.h"
-
 #include <table/e-table-scrolled.h>
 #include <table/e-table-memory-store.h>
 #include <table/e-cell-pixbuf.h>
@@ -41,12 +39,12 @@
 
 struct _EMultiConfigDialogPrivate {
 	GSList *pages;
-	
+
 	GtkWidget *list_e_table;
 	ETableModel *list_e_table_model;
-	
+
 	GtkWidget *notebook;
-	
+
 	int set_page_timeout_id;
 	int set_page_timeout_page;
 };
@@ -87,19 +85,7 @@ create_page_container (const char *description,
 
 	vbox = gtk_vbox_new (FALSE, 0);
 
-#if 0
-	label = e_clipped_label_new (description);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
-
-	separator = gtk_hseparator_new ();
-	gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, TRUE, 0);
-
-	gtk_widget_show (label);
-	gtk_widget_show (separator);
-#endif
-
-	gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0); 
+	gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
 
 	gtk_widget_show (widget);
 	gtk_widget_show (vbox);
@@ -262,7 +248,7 @@ canvas_realize (GtkWidget *widget, EMultiConfigDialog *dialog)
 {
 	int i;
 	int row_count;
-	
+
 	row_count = e_table_model_row_count (dialog->priv->list_e_table_model);
 	for (i = 0; i < row_count; i++) {
 		fill_in_pixbufs (dialog, i);
@@ -299,9 +285,9 @@ e_multi_config_dialog_init (EMultiConfigDialog *multi_config_dialog)
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (multi_config_dialog)->action_area), 12);
 
 	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 12); 
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
 	dialog_vbox = GTK_DIALOG (multi_config_dialog)->vbox;
-	
+
 	gtk_container_add (GTK_CONTAINER (dialog_vbox), hbox);
 
 	list_e_table_model = e_table_memory_store_new (columns);
@@ -350,7 +336,7 @@ e_multi_config_dialog_init (EMultiConfigDialog *multi_config_dialog)
 				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 				NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (multi_config_dialog), GTK_RESPONSE_OK);
-	
+
 
 	gtk_window_set_policy (GTK_WINDOW (multi_config_dialog),
 			       FALSE /* allow_shrink */,
